//@line 36 "/builds/tinderbox/Fx-Mozilla1.8-l10n/Linux_2.4.20-28.8_Clobber/mozilla/browser/locales/../../../l10n/hy-AM/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-l10n/Linux_2.4.20-28.8_Clobber/mozilla/browser/locales/../../../l10n/hy-AM/browser/firefox-l10n.js"

pref("general.useragent.locale", "hy-AM");
